@@ -1,7 +1,11 @@
 context("mr_geo_code")
+custom_skip <- function(){
+  skip_on_cran()
+  skip_if_offline()
+}
 
 test_that("mr_geo_code works for like true fuzzy false", {
-  skip_on_cran()
+  custom_skip()
 
   aa <- mr_geo_code(place = "oost", like = TRUE, fuzzy = FALSE)
 
@@ -12,7 +16,7 @@ test_that("mr_geo_code works for like true fuzzy false", {
 })
 
 test_that("mr_geo_code works for like true fuzzy true", {
-  skip_on_cran()
+  custom_skip()
 
   aa <- mr_geo_code(place = "oost", like = TRUE, fuzzy = TRUE)
 
@@ -23,19 +27,19 @@ test_that("mr_geo_code works for like true fuzzy true", {
 })
 
 test_that("mr_geo_code works for like false fuzzy true", {
-  skip_on_cran()
+  custom_skip()
 
-  aa <- mr_geo_code(place = "oost", like = FALSE, fuzzy = TRUE)
+  aa <- mr_geo_code(place = "oostende", like = FALSE, fuzzy = TRUE)
 
-  expect_is(aa, "list")
-  expect_equal(length(aa), 0)
+  expect_is(aa, "data.frame")
+  expect_true(length(aa) > 0)
 })
 
 test_that("mr_geo_code works for like false fuzzy false", {
-  skip_on_cran()
+  custom_skip()
 
-  aa <- mr_geo_code(place = "oost", like = FALSE, fuzzy = FALSE)
+  aa <- mr_geo_code(place = "oostende", like = FALSE, fuzzy = FALSE)
 
-  expect_is(aa, "list")
-  expect_equal(length(aa), 0)
+  expect_is(aa, "data.frame")
+  expect_true(length(aa) > 0)
 })
